@@ -2477,8 +2477,9 @@ static int fixheader(char *header, int srt)
   int fieldlen1; /* length of one field */
   int f, f1, f2; /* indexes to fields */
   int k, k1; /* indexes to keys */
-  char *headerfield[dap_maxvar]; /* pointers to start of field names and specs */
+  char **headerfield; /* pointers to start of field names and specs */
 
+  headerfield = (char **) dap_malloc(dap_maxvar * sizeof(char *), "headerfield");
   fieldstart = (int *) dap_malloc((dap_maxvar + 1) * sizeof(int), "fieldstart");
   fieldstart[0] = 0;
   fieldlen = (int *) dap_malloc((dap_maxvar + 1) * sizeof(int), "fieldlen");
@@ -2565,6 +2566,7 @@ static int fixheader(char *header, int srt)
 	keymap[k++] = sortord[f];
     }
   write(srt, header, headerlen + 1);
+  dap_free(headerfield, "");
   return headerlen + 1;
 }
 
