@@ -84,7 +84,7 @@ void logreg(char fname[], char yspec[], char x0list[], char x1list[],
 pict *plotlogreg(char *fname, char *yspec, char *x1list, char *style, int ngroups,
 			char *marks, int nmarks, double level);
 void nonparam(char fname[], char variables[], char marks[]);
-void categ(char *dataset, char *varlist, double (*prob)(),
+void categ(char *dataset, char *varlist, char *auxvarlist, double (*prob)(),
 		double param[], char *select, char *partvars, char *trace);
 void loglin(char *fname, char *varlist, char *model0, char *model1, char *part);
 void estimate(char *fname, char *parameters, char *definitions, char *part);
