@@ -388,7 +388,7 @@ static void categ1(double **tab, int ncell, int *varv, int nvar,
   dap_free(info, "");
 }
 
-void categ(char *dname, char *varlist, double (*expect)(),
+void categ(char *dname, char *varlist, char *auxvarlist, double (*expect)(),
 	   double *param, char *select, char *part, char *trace)
 {
   int p;
@@ -402,7 +402,9 @@ void categ(char *dname, char *varlist, double (*expect)(),
   char *partstr;	/* for declaring part variables in covset */
   int *varv;
   int *partv, *partv2;	/* indexes of part variables for catset and covset */
-  int nvar;
+  int ncvar; /* number of classification variables */
+  int navar; /* number of auxiliary variables */
+  int nvar; /* ncvar + navar */
   int npart;
   int more;
   int nparam;	/* number of parameters identified in select */
@@ -447,7 +449,9 @@ void categ(char *dname, char *varlist, double (*expect)(),
     }
   dap_ono = 0;
   inset(filset);
-  nvar = dap_list(varlist, varv, dap_maxvar);
+  ncvar = dap_list(varlist, varv, dap_maxvar);
+  navar = dap_list(auxvarlist, varv + ncvar, dap_maxvar - ncvar);
+  nvar = ncvar + navar;
   for (v = 1; v < nvar; v++)
     {
       if (dap_obs[0].do_len[varv[v]] != DBL)
@@ -1216,7 +1220,7 @@ void loglin(char *fname, char *varlist, char *model0, char *model1, char *part)
   for (p = 1; p < numparam; p++)
     param[p] = 0.0;
 
-  categ(fname1, varlist1, &llexpect, param, select, part, "");
+  categ(fname1, varlist1, "", &llexpect, param, select, part, "");
 
   /* tables are now in catname, going to copy back to fname1 and
    * translate the numerical values back to strings.
