@@ -62,7 +62,7 @@ int ndef;			/* number of defines */
 
 int white(int c)
 {
-  return (c == ' ' || c == '\t' || c == '\n');
+  return (c == ' ' || c == '\t' || c == '\n' || c == '\r');
 }
 
 int alpha(int c)
