@@ -68,6 +68,8 @@ extern int dap_rfilesize;	/* max number of bytes in a memory file */
 extern int dap_maxlines;	/* max number of lines in memory file:
 				 * keep at dap_rfilesize / 8
 				 */
+extern int dap_maxmem; /* memory for sorting */
+extern char *dap_tmpdir; /* temp dir for sorting */
 
 /* Parameters for tables */
 extern int dap_maxrows;		/* max rows for table() */
