@@ -816,10 +816,10 @@ static pict *show1(pict *p)
 	      else		/* not entering or leaving */
 		{
 		  if (inscript)	/* count super/sub-scripted character */
-		    nscript += 1.0;	/*
-					  else		/* count full-sized character */
-		  nfull += 1.0;
-				/* copy bare text, no super/sub-script marks, into baret */
+		    nscript += 1.0;
+		  else		/* count full-sized character */
+		    nfull += 1.0;
+		  /* copy bare text, no super/sub-script marks, into baret */
 		  /* except if ( ), need to escape! */
 		  if (i < dap_maxtxt)
 		    {
