@@ -1171,7 +1171,7 @@ void datatrans(char *step, FILE *dapfile)
   for (v = 0; v < nvars; v++)
     {
       if (len[v] > 0) /* char variable */
-	fprintf(dapfile, "%s[%d] = '\\0';\n", var[v], len[v] + 1);
+	fprintf(dapfile, "%s[%d] = '\\0';\n", var[v], len[v]);
     }
 
   if (!inputisnull)
